==> onos-yang-runtime-2.2.0-b5-sources.jar: org/onosproject/yang/gen/v1/ietfl3vpnsvc/rev20160730/ietfl3vpnsvc/vpnservicemulticast/multicast/rp/DefaultRpGroupMappings.java <==
/*
 * Copyright 2017-present Open Networking Foundation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.onosproject.yang.gen.v1.ietfl3vpnsvc.rev20160730.ietfl3vpnsvc.vpnservicemulticast.multicast.rp;

import java.util.ArrayList;
import java.util.List;
import java.util.Objects;
import java.util.StringJoiner;
import org.onosproject.yang.gen.v1.ietfl3vpnsvc.rev20160730.ietfl3vpnsvc.vpnservicemulticast.multicast.rp.rpgroupmappings.RpGroupMapping;
import org.onosproject.yang.model.InnerModelObject;

/**
 * Represents the implementation of rpGroupMappings.
 *
 * <p>
 * valueLeafFlags identify the leafs whose value are explicitly set
 * Applicable in protocol edit and query operation.
 * </p>
 */
public class DefaultRpGroupMappings extends InnerModelObject implements RpGroupMappings {
    protected List<RpGroupMapping> rpGroupMapping;

    @Override
    public List<RpGroupMapping> rpGroupMapping() {
        return rpGroupMapping;
    }

    @Override
    public void rpGroupMapping(List<RpGroupMapping> rpGroupMapping) {
        this.rpGroupMapping = rpGroupMapping;
    }

    @Override
    public void addToRpGroupMapping(RpGroupMapping addTo) {
        if (rpGroupMapping == null) {
            rpGroupMapping = new ArrayList<>();
        }
        rpGroupMapping.add(addTo);
    }


    @Override
    public int hashCode() {
        return Objects.hash(rpGroupMapping);
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj instanceof DefaultRpGroupMappings) {
            DefaultRpGroupMappings other = (DefaultRpGroupMappings) obj;
            return
                Objects.equals(rpGroupMapping, other.rpGroupMapping);
        }
        return false;
    }

    @Override
    public String toString() {
        return new StringJoiner(", ", getClass().getSimpleName() +"{", "}")
            .add("rpGroupMapping=" + rpGroupMapping)
            .toString();
    }


    /**
     * Creates an instance of defaultRpGroupMappings.
     */
    public DefaultRpGroupMappings() {
    }

}

==> onos-yang-runtime-2.3.1-sources.jar: org/onosproject/yang/gen/v1/ietfl3vpnsvc/rev20160730/ietfl3vpnsvc/vpnservicemulticast/multicast/rp/DefaultRpGroupMappings.java <==
/*
 * Copyright 2017-present Open Networking Foundation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.onosproject.yang.gen.v1.ietfl3vpnsvc.rev20160730.ietfl3vpnsvc.vpnservicemulticast.multicast.rp;

import java.util.ArrayList;
import java.util.List;
import java.util.Objects;
import java.util.StringJoiner;
import org.onosproject.yang.gen.v1.ietfl3vpnsvc.rev20160730.ietfl3vpnsvc.vpnservicemulticast.multicast.rp.rpgroupmappings.RpGroupMapping;
import org.onosproject.yang.model.InnerModelObject;

/**
 * Represents the implementation of rpGroupMappings.
 *
 * <p>
 * valueLeafFlags identify the leafs whose value are explicitly set
 * Applicable in protocol edit and query operation.
 * </p>
 */
public class DefaultRpGroupMappings extends InnerModelObject implements RpGroupMappings {
    protected List<RpGroupMapping> rpGroupMapping;

    @Override
    public List<RpGroupMapping> rpGroupMapping() {
        return rpGroupMapping;
    }

    @Override
    public void rpGroupMapping(List<RpGroupMapping> rpGroupMapping) {
        this.rpGroupMapping = rpGroupMapping;
    }

    @Override
    public void addToRpGroupMapping(RpGroupMapping addTo) {
        if (rpGroupMapping == null) {
            rpGroupMapping = new ArrayList<>();
        }
        rpGroupMapping.add(addTo);
    }


    @Override
    public int hashCode() {
        return Objects.hash(rpGroupMapping);
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj instanceof DefaultRpGroupMappings) {
            DefaultRpGroupMappings other = (DefaultRpGroupMappings) obj;
            return
                Objects.deepEquals(rpGroupMapping, other.rpGroupMapping);
        }
        return false;
    }

    @Override
    public String toString() {
        return new StringJoiner(", ", getClass().getSimpleName() +"{", "}")
            .add("rpGroupMapping=" + rpGroupMapping)
            .toString();
    }


    /**
     * Creates an instance of defaultRpGroupMappings.
     */
    public DefaultRpGroupMappings() {
    }

}
